#!/bin/sh

SERVER="user01@backup.example.com"              # Backup server

LOCAL="/home/user01/Documents/"                 # Local directory
REMOTE="/home/user01/backup/Documents/"         # Remote directory 

LOCAL_TSFILE="/home/user01/.backup_timestamp"   # Local timestamp file
REMOTE_TSFILE="/home/user01/.backup_timestamp"  # Remote timestamp file

function confirm {
	echo -n "$1"
	read answer
	if [[ $answer != "y" ]]; then
		echo "終了します。"
		exit 0
	fi
}

function backup {
	rsync -n -av --delete $LOCAL ${SERVER}:${REMOTE}
	confirm "ローカルファイルをバックアップしますか？(y/n)"
	rsync -av --delete $LOCAL ${SERVER}:${REMOTE}
	ts_local=$( date +%Y%m%d%H%M%S )
	echo -n $ts_local > $LOCAL_TSFILE
	ssh $SERVER "echo -n $ts_local > $REMOTE_TSFILE"
}

function download {
	rsync -n -av --delete ${SERVER}:${REMOTE} $LOCAL
	confirm "リモートファイルをダウンロードしますか？(y/n)"
	rsync -av --delete ${SERVER}:${REMOTE} $LOCAL
	ts_local=$( date +%Y%m%d%H%M%S )
	echo -n $ts_local > $LOCAL_TSFILE
}

ts_remote=$( ssh $SERVER "cat $REMOTE_TSFILE" )
ts_local=$( cat $LOCAL_TSFILE )

echo "リモートファイルのタイムスタンプ: $ts_remote"
echo "ローカルファイルのタイムスタンプ: $ts_local"
echo "----------"

if [[ $1 == "backup" ]]; then
	echo "強制バックアップします。"
	backup
	exit 0
fi

if [[ $1 == "download" ]]; then
	echo "強制ダウンロードします。"
	download
	exit 0
fi

if [[ $ts_local -ge $ts_remote ]]; then
	echo "ローカルファイルは更新されています。"
	backup
	exit 0
fi

if [[ $ts_local -lt $ts_remote ]]; then
	echo "リモートファイルは更新されています。"
	download
	exit 0
fi
